<?php
/*-----------------------------------------------------------------------------------

	Plugin Name: Wolf Portfolio Edited
	Plugin URI: http://wpwolf.com/plugin/wolf-portfolio
	Description: A ready-to-use portfolio custom post type with Isotope filter.
	Version: 1.1
	Author: Constantin Saguin
	Author URI: http://wpwolf.com/about

-----------------------------------------------------------------------------------*/

if ( ! class_exists( 'Wolf_Portfolio' ) ) :

class Wolf_Portfolio {

	var $update_url = 'http://plugins.wpwolf.com/update';

	function __construct() {

		define( 'WOLF_PORTFOLIO_URL', plugins_url().'/'.basename( dirname( __FILE__ ) ) );
		define( 'WOLF_PORTFOLIO_DIR', dirname( __FILE__ ) );

		// Flush rewrite rules on activation
		register_activation_hook( __FILE__, array( &$this, 'activate' ) );

		// load text domain
		add_action( 'init', array( &$this, 'plugin_textdomain' ) );
		
		// register post type
		add_action( 'init', array( &$this, 'register_post_type') );

		// register taxonomy
		add_action( 'init', array( &$this, 'register_taxonomy') );

		// add portfolio image sizes
		add_image_size( 'portfolio-thumb', 600, 450, true );
		add_image_size( 'portfolio-image', 960, 5000, false );
		
		// set default options
		add_action( 'after_setup_theme', array( &$this, 'default_options' ) );
		
		// add work metaboxes
		add_action( 'add_meta_boxes', array( &$this, 'add_metabox') );
		add_action( 'save_post', array( &$this, 'save_post_meta') );

		// enqueue isotope
		add_action('wp_enqueue_scripts', array( &$this, 'enqueue_script' ) );

		// fire isotope
		add_action('wp_head', array( &$this, 'fire_isotope' ) );

		// add options page
		add_action( 'admin_init', array( &$this, 'admin_init' ) );
		add_action( 'admin_menu', array( &$this, 'add_menu' ) );
		
		// check if templates have been copied in the themes
		add_action( 'admin_notices', array( &$this, 'error_notice' ) );

		// plugin update notification
		add_action( 'admin_init', array( &$this, 'plugin_update' ) );

	}

	// --------------------------------------------------------------------------

	function activate( $network_wide ) {

		add_option( 'wolf_portfolio_flush', true );

	} // end activate

	// --------------------------------------------------------------------------

	/**
	 * Loads the plugin text domain for translation
	 */
	function plugin_textdomain() {

		$domain = 'wolf';
		$locale = apply_filters( 'wolf', get_locale(), $domain );
		load_textdomain( $domain, WP_LANG_DIR.'/'.$domain.'/'.$domain.'-'.$locale.'.mo' );
		load_plugin_textdomain( $domain, FALSE, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );

	} // end plugin_textdomain

	// --------------------------------------------------------------------------

	// --------------------------------------------------------------------------

	/**
	 * Enqueue Isotope if option is checked
	 */
	function enqueue_script() {

		if ( $this->get_option( 'isotope' ) ) {

			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'isotope', WOLF_PORTFOLIO_URL . '/js/jquery.isotope.min.js', 'jquery', '1.5.25', true );
		
		}

	}

	// --------------------------------------------------------------------------

	/**
	 * Fire isotope plugin
	 */
	function fire_isotope() {

		if ( $this->get_option( 'isotope' ) ) {

			echo '<script type="text/javascript">
// portfolio isotope
jQuery( function( $ ) {
	
	$( "#work-grid" ).imagesLoaded( function() {
		$( "#work-grid" ).isotope( {
			itemSelector : ".work-item"
		} );
	});

	var optionFilter = $( "#work-filter ul" ),
	optionFilterLinks = optionFilter.find( "a" );
	optionFilterLinks.attr( "href", "#" );

	optionFilterLinks.click( function() {
		var selector = $( this ).attr( "data-filter" );
		$( "#work-grid" ).isotope( { 
			filter : "." + selector, 
			itemSelector : ".work-item",
			layoutMode : "fitRows",
			animationEngine : "best-available"
		});

		// Highlight the correct filter
		optionFilterLinks.removeClass( "active" );
		$(this).addClass( "active" );
		return false;
	});
} );
</script>';
		
		}

	}

	// --------------------------------------------------------------------------

	/**
	 * Register work post type
	 */
	function register_post_type() {

		$labels = array( 
			'name' => _x( 'Works', 'wolf' ),
			'singular_name' => _x( 'Work', 'wolf' ),
			'add_new' => _x( 'Add New', 'wolf' ),
			'add_new_item' => _x( 'Add New Work', 'wolf' ),
			'all_items'  =>  _x( 'All Works', 'wolf' ),
			'edit_item' => _x( 'Edit Work', 'wolf' ),
			'new_item' => _x( 'New Work', 'wolf' ),
			'view_item' => _x( 'View Work', 'wolf' ),
			'search_items' => _x( 'Search Works', 'wolf' ),
			'not_found' => _x( 'No works found', 'wolf' ),
			'not_found_in_trash' => _x( 'No works found in Trash', 'wolf' ),
			'parent_item_colon' => '',
			'menu_name' => _x( 'Portfolio', 'wolf' ),
		);

		$args = array( 

			'labels' => $labels,
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true,
			'show_in_menu' => true,
			'query_var' => false,
			'rewrite' => array( 'slug' => 'work' ),
			'capability_type' => 'post',
			'has_archive' => false,
			'hierarchical' => false,
			'menu_position' => 5,
			'taxonomies' => array(),
			'supports' => array( 'title', 'editor', 'author', 'post-formats', 'thumbnail', 'custom-fields', 'comments' ),
			'exclude_from_search' => false,

			'description' => __( 'Present your work', 'wolf' ),
			'menu_icon' => WOLF_PORTFOLIO_URL . '/menu.png',
		);

		register_post_type( 'work', $args );


	}

	// --------------------------------------------------------------------------

	/**
	 * Register register_taxonomy
	 */
	function register_taxonomy() {

		$labels = array( 
			'name' => _x( 'Work Types', 'wolf' ),
			'singular_name' => _x( 'Work Type', 'wolf' ),
			'search_items' => _x( 'Search Work Types', 'wolf' ),
			'popular_items' => _x( 'Popular Work Types', 'wolf' ),
			'all_items' => _x( 'All Work Types', 'wolf' ),
			'parent_item' => _x( 'Parent Work Type', 'wolf' ),
			'parent_item_colon' => _x( 'Parent Work Type:', 'wolf' ),
			'edit_item' => _x( 'Edit Work Type', 'wolf' ),
			'update_item' => _x( 'Update Work Type', 'wolf' ),
			'add_new_item' => _x( 'Add New Work Type', 'wolf' ),
			'new_item_name' => _x( 'New Work Type', 'wolf' ),
			'separate_items_with_commas' => _x( 'Separate work types with commas', 'wolf' ),
			'add_or_remove_items' => _x( 'Add or remove work types', 'wolf' ),
			'choose_from_most_used' => _x( 'Choose from the most used work types', 'wolf' ),
			'menu_name' => _x( 'Types', 'wolf' ),
		);

		$args = array( 
			
			'labels' => $labels,
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'work-type', 'with_front' => false),
		);

    		register_taxonomy( 'work_type', array( 'work' ), $args );

    		// Check the option we set on activation.
		if ( get_option('wolf_portfolio_flush') == true ) {
			flush_rewrite_rules();
			delete_option('wolf_portfolio_flush');
		}

	}

	// --------------------------------------------------------------------------

	/**
	 * Add metabox
	 */
	function add_metabox() {

		add_meta_box(
			'work_details',
			__( 'Work Details', 'wolf' ),
			array( &$this, 'render_metabox' ),
			'work'
		);

	}

	// --------------------------------------------------------------------------

	/**
	 * Render metabox
	 */
	function render_metabox( $post ) {

		wp_nonce_field( plugin_basename( __FILE__ ), 'wolf_portfolio_nonce' );

		$client = get_post_meta( $post->ID, '_work_client', true );
		
		echo '<label for="work_client">';
		_e( 'Client', 'wolf' );
		echo '</label><br>';
		echo '<input type="text" id="work_client" name="work_client" value="' . esc_attr( $client ) . '" size="25" />';

		$link = get_post_meta( $post->ID, '_work_link', true );
		
		echo '<br><br>';

		echo '<label for="work_link">';
		_e( 'Project Link', 'wolf' );
		echo '</label><br>';
		echo '<input type="text" id="work_link" name="work_link" value="' . esc_url( $link ) . '" size="25" />';

	}

	// --------------------------------------------------------------------------

	/**
	 * When the post is saved, saves our custom data 
	 */
	function save_post_meta( $post_id ) {

		if( !isset($_POST['post_type']) )
			return;

		if ( 'page' == $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_page', $post_id ) )
				return;
		} else {
			if ( ! current_user_can( 'edit_post', $post_id ) )
				return;
		}

		// Secondly we need to check if the user intended to change this value.
		if ( ! isset( $_POST['wolf_portfolio_nonce'] ) || ! wp_verify_nonce( $_POST['wolf_portfolio_nonce'], plugin_basename( __FILE__ ) ) )
		return;

		// Thirdly we can save the value to the database

		//if saving in a custom table, get post_ID
		$post_ID = $_POST['post_ID'];
		//sanitize user input
		$work_client = sanitize_text_field( $_POST['work_client'] );
		$work_link = esc_url( $_POST['work_link'] );

		// Do something with $work_client 
		// either using 
		add_post_meta($post_ID, '_work_client', $work_client, true) or
		update_post_meta($post_ID, '_work_client', $work_client);
		
		add_post_meta($post_ID, '_work_link', $work_link, true) or
		update_post_meta($post_ID, '_work_link', $work_link);
	}


	// --------------------------------------------------------------------------

	/**
	 * Add options sub-menu
	 */
	function add_menu() {

		add_submenu_page( 'edit.php?post_type=work', __( 'Options', 'wolf' ), __( 'Options', 'wolf' ), 'edit_plugins', 'wolf-work-options', array( &$this, 'form' ) );
	}

	// --------------------------------------------------------------------------

	/**
	 * Set default settings
	 */
	function default_options() {
		
		global $options;

		if ( false ===  get_option('wolf_work_settings')  ) {

			$default = array(

				'use_css' => 1,
				'isotope' => 1

			);

			add_option( 'wolf_work_settings', $default );
		}
	}

	// --------------------------------------------------------------------------

	/**
	 * Get options
	 */
	function get_option( $value = null ) {
		
		global $options;
	            
 		$wolf_work_settings = get_option('wolf_work_settings');
		
		if ( isset( $wolf_work_settings[ $value ] ) ){
			return $wolf_work_settings[ $value ];
		}
			
	}

	// --------------------------------------------------------------------------

	/**
	 * Init Settings
	 */
	function admin_init() {

		register_setting( 'wolf-work-settings', 'wolf_work_settings', array( &$this, 'settings_validate' ) );
		add_settings_section( 'wolf-work-settings', '', array( &$this, 'section_intro' ), 'wolf-work-settings' );
		add_settings_field( 'use_css', __( 'Use plugin CSS', 'wolf' ), array( &$this, 'setting_use_css' ), 'wolf-work-settings', 'wolf-work-settings' );
		add_settings_field( 'isotope', __( 'Use isotope filter', 'wolf' ), array( &$this, 'setting_isotope' ), 'wolf-work-settings', 'wolf-work-settings' );
		add_settings_field( 'info', __( 'Info', 'wolf' ), array( &$this, 'setting_info' ), 'wolf-work-settings', 'wolf-work-settings' );

	}

	// --------------------------------------------------------------------------

	/**
	 * Validate settings
	 */
	function settings_validate( $input ) {
		
		$input['use_css'] = intval( $input['use_css'] );
		$input['isotope'] = intval( $input['isotope'] );
		return $input;
	}

	// --------------------------------------------------------------------------

	/**
	 * Intro ( used for debug )
	 */
	function section_intro() {
		// debug
		//global $options;
		//var_dump(get_option('wolf_work_settings'));
	}

	// --------------------------------------------------------------------------

	/**
	 * Info
	 */
	function setting_info() {
		
		
		echo "<p>";
		_e( 'The plugin has created the portfolio templates in your theme folder.<br>Feel free to edit the portfolio templates', 'wolf' );
		
		echo ' : <code>single-work.php</code> and <code>taxonomy-work_type.php</code>';
		
		echo "</p>";

		echo "<p><em>";
		printf( __( 'If a portfolio page returns a 404 error, refresh your <a href="%s">permalink structure</a>', 'wolf' ), 
			esc_url( admin_url( '/options-permalink.php' ) 
			) 
		);
		echo "</p></em>";

	}

	// --------------------------------------------------------------------------

	/**
	 * Use custom style
	 */
	function setting_use_css() {
		?>
		<input type="hidden" name="wolf_work_settings[use_css]" value="0">
		<label><input type="checkbox" name="wolf_work_settings[use_css]" value="1" <?php echo ( ( $this->get_option( 'use_css' ) == 1) ? ' checked="checked"' : '' ); ?>>
		</label>
		<?php
	}

	// --------------------------------------------------------------------------

	/**
	 * Use isotope filter
	 */
	function setting_isotope() {
		?>
		<input type="hidden" name="wolf_work_settings[isotope]" value="0">
		<label><input type="checkbox" name="wolf_work_settings[isotope]" value="1" <?php echo ( ( $this->get_option( 'isotope' ) == 1) ? ' checked="checked"' : '' ); ?>>
		</label>
		<?php
	}

	// --------------------------------------------------------------------------

	/**
	 * Options form
	 */
	function form() {
		?>
		<div class="wrap">
			<div id="icon-options-general" class="icon32"></div>
			<h2><?php _e( 'Portfolio Options' ) ?></h2>
			<form action="options.php" method="post">
				<?php settings_fields( 'wolf-work-settings' ); ?>
				<?php do_settings_sections( 'wolf-work-settings' ); ?>
				<p class="submit"><input name="save" type="submit" class="button-primary" value="<?php _e( 'Save Changes', 'wolf' ); ?>" /></p>
			</form>
		</div>
		<?php
	}

	// --------------------------------------------------------------------------

	/**
	 * Copy portfolio and taxonomy templates in theme folder
	 */
	function create_template() {
			
		$errors = array();
		$template_tax = WOLF_PORTFOLIO_DIR . '/taxonomy-work_type.php';
		$template_single = WOLF_PORTFOLIO_DIR . '/single-work.php';
		$theme_dir = get_template_directory();

		if ( ! is_file( $theme_dir . '/taxonomy-work_type.php' ) ) {
			
			if ( ! copy( $template_tax, $theme_dir . '/taxonomy-work_type.php' ) ) {
				
				$errors['taxonomy'] = 'taxonomy-work_type.php';		
			}
				
		}

		if ( ! is_file( $theme_dir . '/single-work.php' ) ) {
			
			if ( ! copy( $template_single, $theme_dir . '/single-work.php' ) ) {
				
				$errors['single page'] = 'single-work.php';		
			}
				
		}

		if ( $errors == array() ) {
			
			return 'OK';

		} else {
			
			return $errors;
		}
		
	}

	// --------------------------------------------------------------------------

	/**
	 * Display errors if template couldn't be copied in the theme folder
	 */
	function error_notice() {
		
		if ( $this->create_template() != 'OK' ) {
			
			$errors = $this->create_template();

			$output = '<div class="wrap"><div class="error">';
			
			foreach ( $errors as $name => $error_file ) {
				$output .= '</p>';
				$output .= sprintf( __( 'Error creating the %1$s template. Copy the file %2$s into the %3$s theme folder to fix the issue', 'wolf' ),
					$name,
					'<code>' . str_replace( network_site_url(), '', WOLF_PORTFOLIO_URL . '/' . $error_file ) . '</code>', 
					'<code>' . str_replace( network_site_url(), '', get_stylesheet_directory_uri() ).'</code>' );
				$output .= '</p>';
			}
			

			$output .= '</div></div>';
			
			echo $output;
		}
	}

	// --------------------------------------------------------------------------

	/**
	 * Single work post navigation
	 */
	function navigation() {
		global $post;

		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
		$next = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous )
			return;
		?>
		<nav class="work-navigation" role="navigation">
			<?php previous_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'wolf' ) ); ?>
			<?php next_post_link( '%link', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'wolf' ) ); ?>
		</nav><!-- .navigation -->
		<?php
	}

	// --------------------------------------------------------------------------

	/**
	 * Plugin update notification
	 */
	function plugin_update() {
		
		$plugin_data = get_plugin_data( __FILE__ );

		$current_version = $plugin_data['Version'];
		$plugin_slug = plugin_basename( dirname( __FILE__ ) );
		$plugin_path = plugin_basename( __FILE__ );
		$remote_path = $this->update_url . '/' . $plugin_slug;
		
		if ( ! class_exists( 'Wolf_WP_Update' ) )
			include_once('class/class-wp-update.php');
		
		new Wolf_WP_Update( $current_version, $remote_path, $plugin_path );
	}

} // end class
endif;

$wolf_portfolio = new Wolf_Portfolio;

if( ! function_exists( 'wolf_work_nav' ) ):
/**
 * Displays navigation to next/previous post when applicable.
 */
function wolf_work_nav() {
	
	global $wolf_portfolio;
	return $wolf_portfolio->navigation();

}
endif;


if( ! function_exists( 'wolf_get_portfolio_url' ) ):
/**
 * Returns the URL of the portfolio page
 */
function wolf_get_portfolio_url() {
	
	global $wolf_portfolio;
	return $wolf_portfolio->get_portfolio_url();

}
endif;

if( ! function_exists( 'wolf_get_isotope_option' ) ):
/**
 * Returns the URL of the portfolio page
 */
function wolf_get_isotope_option() {
	
	global $wolf_portfolio;
	return $wolf_portfolio->get_option( 'isotope' );

}
endif;